from PyQt5.QtWidgets import QDialog, QPushButton, QLineEdit, QApplication, QLabel, qApp
from PyQt5.QtGui import QFont


class UserNameDialog(QDialog):
    """Класс формы логирования пользователя при входе."""
    def __init__(self):
        super().__init__()

        self.ok_pressed = False

        # Форма
        self.setWindowTitle('Вход в приложение')
        self.setFixedSize(300, 130)

        #  --- Имя пользователя
        self.label = QLabel('Имя пользователя:', self)
        self.label.move(10, 12)
        self.label.setFixedSize(150, 10)
        self.label.setFont(QFont("Arial", 8, QFont.Bold))

        self.client_name = QLineEdit(self)
        self.client_name.move(140, 10)
        self.client_name.setFixedSize(150, 25)

        # --- Пароль
        self.label_passwd = QLabel('Пароль:', self)
        self.label_passwd.move(10, 42)
        self.label_passwd.setFixedSize(150, 20)
        self.label_passwd.setFont(QFont("Arial", 8, QFont.Bold))

        self.client_passwd = QLineEdit(self)
        self.client_passwd.move(140, 48)
        self.client_passwd.setFixedSize(150, 25)
        self.client_passwd.setEchoMode(QLineEdit.Password)

        # кнопки
        self.btn_ok = QPushButton('Начать', self)
        self.btn_ok.move(45, 85)
        self.btn_ok.clicked.connect(self.click)
        self.btn_ok.setFixedSize(100, 30)

        # вторую кнопку делаем по расположению зависимой от первой
        self.btn_cancel = QPushButton('Выход', self)
        self.btn_cancel.move(self.btn_ok.x() + self.btn_ok.width() + 5, self.btn_ok.y())
        self.btn_cancel.clicked.connect(qApp.exit)
        self.btn_cancel.setFixedSize(self.btn_ok.width(), self.btn_ok.height())

        self.show()

    # Обработчик кнопки ОК, если поле ввода не пустое, ставим флаг и завершаем приложение.
    def click(self):
        if self.client_name.text():
            self.ok_pressed = True
            qApp.exit()


if __name__ == '__main__':
    app = QApplication([])
    dial = UserNameDialog()
    app.exec_()



# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information
import os
import sys
path = os.path.dirname(os.path.dirname(os.path.abspath('')))
sys.path.insert(0, path)


project = 'Messenger'
copyright = '2022, Pavel Zhirnov'
author = 'Pavel Zhirnov'
release = '001'

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = [
    'sphinx.ext.duration',
    'sphinx.ext.doctest',
    'sphinx.ext.autodoc',
]

templates_path = ['_templates']
exclude_patterns = []



# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

html_theme = 'alabaster'
html_static_path = ['_static']



import sys
import os
import unittest
from server.core import MessageProcessor

sys.path.insert(0, os.path.join(os.getcwd(), '../..'))

from common.variables import ACTION, ACCOUNT_NAME, RESPONSE, PRESENCE, ERROR, TIME, USER


class TestServer(unittest.TestCase):
    """
    Тестрирование сервера - ф-ия process_client_msg
    """
    ok_dict = {
        RESPONSE: 200,
    }

    err_dict = {
        RESPONSE: 400,
        ERROR: 'Bad request'
    }

    def test_ok_check(self):
        """
        Проверяется корректный запрос - ответ должен быть 200
        """
        self.assertEqual(
            MessageProcessor.process_message(
                {ACTION: PRESENCE, TIME: 1.1, USER: {ACCOUNT_NAME: 'Guest'}}
            ), self.ok_dict
        )

    def test_no_action(self):
        """
        Действие не указано
        """
        self.assertEqual(
            MessageProcessor.process_message(
                {TIME: 1.1, USER: {ACCOUNT_NAME: 'Guest'}}
            ), self.err_dict
        )

    def test_no_time(self):
        """
        Действие не указано
        """
        self.assertEqual(
            MessageProcessor.process_message(
                {ACTION: PRESENCE, USER: {ACCOUNT_NAME: 'Guest'}}
            ), self.err_dict
        )

    def test_wrong_action(self):
        """
        Действие не указано
        """
        self.assertEqual(
            MessageProcessor.process_message(
                {ACTION: 'no action', TIME: 1.1, USER: {ACCOUNT_NAME: 'Guest'}}
            ), self.err_dict
        )

    def test_account_name(self):
        """
        Проверка имени пользователя
        """
        self.assertEqual(
            MessageProcessor.process_message(
                {ACTION: PRESENCE, TIME: 1.1, USER: {ACCOUNT_NAME: 'Bad name'}}
            ), self.err_dict
        )

    def test_response_dict(self):
        """
        Проверка того, что фнкция возвращает словарь - при 200 и 400
        """
        # assertNotEqual
        self.assertIsInstance(
            MessageProcessor.process_message(
                {ACTION: PRESENCE, TIME: 1.1, USER: {ACCOUNT_NAME: 'Guest'}}
            ), dict
        )
        self.assertIsInstance(
            MessageProcessor.process_message(
                {ACTION: PRESENCE, }
            ), dict
        )

    def test_response_empty_param(self):
        """
        Проверка случая, когда в функцию не был передан параметр
        """
        with self.assertRaises(TypeError):
            MessageProcessor.process_message()


if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages

setup(name="py_bestmess_client",
      version="0.1.0",
      description="Mess Client",
      author="Pavel Zhirnov",
      author_email="pavel@inbox.ru",
      packages=find_packages(),
      install_requires=['PyQt5', 'sqlalchemy', 'pycryptodome', 'pycryptodomex']
      )
